#[derive(WithRustyHandlebars)]
{
// Attributes available to this derive:
#[template]
}
Derive macro for implementing Handlebars templating on structs Derive macro for implementing Handlebars templating
#[derive(WithRustyHandlebars)]
{
// Attributes available to this derive:
#[template]
}
Derive macro for implementing Handlebars templating on structs Derive macro for implementing Handlebars templating